@@ -4,7 +4,7 @@
 
 import sys
 
-from pwbus_request.request import request
+from pwbus_request.request import Request
 
 # PwbusBootleRequest
 #
