@@ -57,8 +57,7 @@ class Request():
 
     def post(self, payload, headers, text_response=True):
         try:
-            print("Debug: isRetry", self.isRetry() )
-            if 'pwbus-correlation-id' in headers:
+            if self.isRetry():
                 data = requests.post(
                     "http://pwbus-http/pwbus/v1/retry",
                     data={},
